# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2023 Valory AG
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------

"""Test the rounds of the skill."""
from unittest.mock import MagicMock

from packages.valory.skills.test_ipfs_abci.rounds import IpfsRound


def test_end_block() -> None:
    """Test IpfsRound.end_block()"""
    dummy_round = IpfsRound(
        synchronized_data=MagicMock(max_participants=4),
    )
    dummy_round.end_block()
